Seed-mediated atomic-scale reconstruction of silver manganate nanoplates for oxygen reduction towards high-energy aluminum-air flow batteries | Nature Communications
Author: Jaechan Ryu
Description: Aluminum–air batteries are promising candidates for next-generation high-energy-density storage, but the inherent limitations hinder their practical use. Here, we show that silver nanoparticle-mediated silver manganate nanoplates are a highly active and chemically stable catalyst for oxygen reduction in alkaline media. By means of atomic-resolved transmission electron microscopy, we find that the formation of stripe patterns on the surface of a silver manganate nanoplate originates from the zigzag atomic arrangement of silver and manganese, creating a high concentration of dislocations in the crystal lattice. This structure can provide high electrical conductivity with low electrode resistance and abundant active sites for ion adsorption. The catalyst exhibits outstanding performance in a flow-based aluminum–air battery, demonstrating high gravimetric and volumetric energy densities of ~2552 Wh kgAl−1 and ~6890 Wh lAl−1 at 100 mA cm−2, as well as high stability during a mechanical rech [cell cut: 1319 characters, first 1000 kept]
Keywords: Batteries
Date: 2018-09-13

Skip to main content

Advertisement

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

A Nature Research Journal

Menu

#

Search E-alert Submit My Account Login

- Article
- Open Access
- Published: 13 September 2018

# Seed-mediated atomic-scale reconstruction of silver manganate nanoplates for oxygen reduction towards high-energy aluminum-air flow batteries

- Jaechan Ryu1 na1,
- Haeseong Jang ORCID: orcid.org/0000-0002-1301-86271 na1,
- Joohyuk Park1 nAff2,
- Youngshin Yoo1,
- Minjoon Park
  ORCID: orcid.org/0000-0002-3526-62931 &
- Jaephil Cho
  1

Nature Communications volume 9, Article number: 3715 (2018) Cite this article

- 5723 Accesses

- 17 Citations

- 52 Altmetric

- Metrics details

### Subjects

- Batteries
- Electrochemistry

## Abstract

Aluminum–air batteries are promising candidates for next-generation high-energy-density storage, but the inherent limitations hinder their practical use. Here, we show that silver nanoparticle-mediated silver manganate nanoplates are a highly active and chemically stable catalyst for oxygen reduction in alkaline media. By means of atomic-resolved transmission electron microscopy, we find that the formation of stripe patterns on the surface of a silver manganate nanoplate originates from the zigzag atomic arrangement of silver and manganese, creating a high concentration of dislocations in the crystal lattice. This structure can provide high electrical conductivity with low electrode resistance and abundant active sites for ion adsorption. The catalyst exhibits outstanding performance in a flow-based aluminum–air battery, demonstrating high gravimetric and volumetric energy densities of ~2552 Wh kgAl−1 and ~6890 Wh lAl−1 at 100 mA cm−2, as well as high stability during a mechanical recharging process.

Download PDF

## Introduction

Metal–air cells have been highlighted as next-generation batteries, providing the possibilities of low cost and high-energy storage1. Aqueous aluminum–air batteries (AABs) are a promising candidate for efficient power delivery in the field of transportation and uninterrupted power supply because of its high-energy density (theoretically, ~8131 W h kgAl−1 and ~21,954 W h LAl−1, see Supplementary Note 1) with abundant reserves, low cost, and light weight of aluminum (26.98 g mol−1)2,3. In particular, aluminum has the highest volumetric capacity (~8.04 A h cm−3) among the electrode materials (e.g., Li: ~2.06, Mg: ~3.83, and Zn: ~5.85 A h cm−3)4. However, there are several hurdles that need to be overcome for the practical application of the AABs, such as high corrosion rate of aluminum anodes, rapid self-discharge, and precipitation of solid by-products (Al(OH)3 and Al2O3) on the surface of electrodes5,6,7. Thus, technical progress has been mainly limited to the mismatch between theoretical and practical performances (< 1000 W h kgAl−1)8,9. To date, intensive efforts have been devoted to overcome the above-mentioned issues by developing a proper aluminum alloy as anodes10,11,12, electrolytes13,14,15, and cell designs16,17. Recently, AABs with Cu/Cu2O nanoparticles and Cu–N–C with the Ketjenblack supports were reported by using a sacrificial Cu-based metal–organic framework, showing a stable discharge of 1.53 V at 40 mA cm−2 with the aid of additives18. In terms of the cell design, AABs containing two different electrolytes were also reported15 and demonstrated a specific discharge capacity of ~1810 mA h gAl−1 and energy of ~2081 W h kgAl−1 at a current density of 20 mA cm−2. In addition, Shim et al. fabricated deformable AABs with the high degree levels, which exhibited a specific capacity of 496 mA h gAl−1 at a current density of 5 µA cm−2.19 However, its poor rate capability with low current density still limited the practical use. Thus, it is urgent to develop highly efficient, feasible alternative approaches. There is an additional intrinsic problem in AABs, which is a sluggish rate of the oxygen reduction reaction (ORR). Research into electrocatalyts for ORR can be categorized into metal- and carbon-based materials20,21,22,23,24,25,26,27,28,29,30,31,32. With respect to the lifetime of an air electrode, the carbon could facilitate the formation of hydroperoxide during ORR33; thus, carbon-free metal or metal oxides have been widely studied34,35,36,37,38. Manganese oxides have emerged as an efficient electrocatalyst for ORR,39,40,41 showing high catalytic activity according to their chemical structures and morphologies such as nanowires42,43, nanorods44,45, and nanoplates46. In particular, plate-like manganese oxides have attracted tremendous research interest because of their unique physiochemical properties with well-defined interfaces, which have been applied to a range of electrochemical devices47. However, typical oxides have low electrical conductivity, which can be enhanced by introducing highly conductive precious metals such as platinum48, palladium49, or silver30,50,51. Among them, silver has several appealing features, such as approximately 50 times lower cost and less susceptibility in alkaline solution in comparison to platinum34. Currently, several silver manganese oxide materials and alloys have been reported, for example, Ag–MnOx nanowire50, Ag–MnO2 on reduced graphene oxide51, and Ag–MnOx carbon composite52. However, a critical question remains with regard to how the silver element can improve the catalytic activity of manganese oxide in terms of the atomic structure.

In this study, we demonstrate the incorporation of silver atoms on a plate-like manganese oxide via a metal seed-mediated growth method. This enables the formation of a striped silver manganate structure with abundant surface dislocations, leading to high catalytic activity and electron transfer rate for ORR. Additionally, we develop a flow-based aluminum–air battery to alleviate the side reactions in the cell, where the electrolytes can be continuously circulated. Remarkably, the precipitation problem has been addressed, achieving the unprecedented energy density of ~2552 W h kgAl−1 (~6861 W h LAl−1) at a high current density of 100 mA cm−2.

## Results

### Electrocatalyst preparation and characterization

Our unique strategy enables the formation of silver metal seed-mediated silver manganate nanoplates (hereafter referred to as SMNp) by simple precipitation and heat-treatment methods. Briefly, the manganese precursor and silver nanoparticles functionalized with polyvinylpyrrolidone as a chelating agent were dispersed in ethanol solution, and then NaOH as a reducing agent was added under stirring. After the precipitation reaction was completed, the prepared manganese hydroxide with a silver nanoparticle was calcined at 450 °C for 15 min (see Methods). Figure 1a shows the schematic of different morphologies of each sample according to synthesis conditions. For comparison, bulk manganese oxide (BM) and polyhedron manganese oxide (PM) were prepared without a reducing agent or silver metal seed, respectively. One observation is that the incorporation of silver metal in a manganese hydroxide precursor enabled the growth of the plate-like SMNp, in which silver nanoparticles could act as a growth seed (Supplementary Fig. 1). The lower coordination of surface atoms (typical low-index (111) or (100)) was reported to induce the internal lattice strain to minimize the surface energy46. In our case, the silver nanoparticles in the SMNp, which has a low index of (111) and a particle size of < 100 nm are expected to induce the similar structural disorder, thus generating surface strain in MnOx.

Fig. 1

Formation of the stripe pattern and dislocation. a, b Schematic of the synthesis process (a) of the bulk manganese oxides (BM), polyhedron manganese oxide (PM), and silver manganate nanoplate (SMNp), and the summary of the catalytic effects (b) of the SMNp. c–e Scanning electronic microscopy (SEM) images of the BM (c), PM (d), and SMNp (e) showing plate-like structures with silver nanoparticles. f, g High-resolution transmission electron microscopy (HR-TEM) images of the SMNp (f) and high-magnified image (g) of the box in f, which shows zigzag atomic arrangements with intragranular cracking. Fast Fourier transform (FFT) image of g presents the lattice planes of (–100) and (001) along the [010] zone, indicating the orthorhombic structure of Ag2MnO4. h, i Inverse FFT images of applied masks at the blue circle (h) and red circle (i) in g, showing a wide range of dislocations with defects. The dislocations are shown by circles and edge dislocations are represented by a T-shaped symbol. The upper right insets in h and i indicate the applied masks and the lattice spacing of the (101) plane is denoted as the left inset in h. Scale bars, 5 μm (c), 500 nm (d), 200 nm (e), 100 nm (f), 4 nm (g), and 1 nm (h, i)

Full size image

In addition, the unique striped patterns with intragranular defects were observed in the SMNp, which could be ascribed to the zigzag atomic arrangements of silver and manganese elements. This result implied that as growth proceeded during heat treatment, the silver atom could move to the available site on the manganese substrate by creating the orthorhombic crystal structure of Ag2MnO4. Figure 1b summarized the catalytic effect of the SMNp in terms of the electrochemical properties, which will be discussed in detail.

The scanning electron microscopy (SEM) of the BM shows that the particle shape was bulky agglomerates with a size of ~15 µm because of the lack of additives for the morphology control (Fig. 1c), and X-ray diffraction (XRD) pattern indicated that it contained different phases of α-Mn2O3 and β-MnO2 (Supplementary Fig. 2a). In contrast, the PM showed nano-sized polycrystalline structure with a size of ~100 nm (Fig. 1d), and consisted of mixed Mn3O4 and Mn5O8 phases (Supplementary Fig. 2b). We used a crystalline silver metal seed having an average size of ~100 nm, which is typically enclosed by four facets, for example, (111), (200), (220), and (311), as shown in Supplementary Fig. 2c. By using this metal seed, the plate-like configuration of the SMNp was obtained with distributed silver nanoparticles on the surface (Fig. 1e), showing a thickness of 30–40 nm (Supplementary Figs. 3, 4). Energy-dispersive X-ray spectroscopy (EDX) mapping revealed that the SMNp was composed of the silver, manganese, and oxygen atoms (Supplementary Fig. 5), and XRD analysis also exhibited four different phases of Ag, Ag2O, Ag2MnO4, and Mn3O4 (Supplementary Fig. 2d). This result was consistent with the chemical position data from X-ray photoelectron spectroscopy (XPS) analysis. The Ag 3d, Mn 2p, and O 1s core levels from the SMNp structure exhibited the pronounced peaks related to the Ag2O and Mn3O4 at 367.5, 373.5, 529.7, and 641.7 eV (Supplementary Fig. 6). We also measured the specific surface areas of the BM, PM, and SMNp, showing the values of 4.97, 14.18, and 11.47 m2g–1, respectively, where the PM showed the highest value because it consisted of the nanoparticles (Supplementary Table 1).

High-resolution transmission electron microscopy (HR-TEM) image of the SMNp clearly showed the striped patterns on the surface along with a wide range of dislocations and intragranular defects (Fig. 1f, g). The fast Fourier transform (FFT) image of the SMNp showed the orthorhombic phases on the basis of the unit spots of (−100) and (001) along the [010] zone axis, which are consistent with XRD results of Ag2MnO4 (space group: Pnma). This implies that the structure of nanoplate parts in the SMNp was Ag2MnO4 and not manganese oxide itself. To understand the complex structures of the SMNp, inverse FFT images were obtained by applying different masks on it along the [010] zone axis (Fig. 1h, i). Apparently, a high concentration of dislocations with crystal defects was discovered on the striped structures of the SMNp, and the other zone axis of [123] direction also showed similar results. Notably, from the dislocation edges, d-spacing value was increased from ~0.389 to ~1.124 nm, indicating continuously propagated defects (Supplementary Fig. 7). These dislocation edges could act as the nucleation sites, generating the intragranular cracks53. The evolution of dislocation could be originated from the different atomic size of silver and manganese elements within the crystal lattice. The larger atomic size of the silver element than the manganese element could trigger a substantial lattice strain in the nanoplate, which significantly dislodges nearby atoms and generates an anisotropic defect structure in the SMNp54. In terms of catalytic activity, the exposed defects may provide abundant active sites and ionic channels, reinforcing the ion transport kinetics. To clarify the morphology change and the concentration of dislocations of the SMNp, the control experiment with different amounts of precursors (silver nanoparticle, manganese source, and reducing agent) was conducted (see Methods), which was summarized in Supplementary Figs. 8–10. As a result, increasing the amounts of silver nanoparticles reduced the concentration of dislocations with lower defects, showing high crystallinity of selected area electron diffraction (SAED) patterns (Supplementary Fig. 8). On the contrary, nanoplate morphology was not observed when both amounts of manganese and the reducing agent were controlled (Supplementary Figs. 9, 10). This implied that the seed-mediated growth for forming nanoplate morphology required appropriate contents of manganese source and the reducing agent.

To further confirm the origin of striped pattern on the SMNp, we performed atomically resolved scanning transmission electron microscopy (STEM) and electron energy loss spectroscopy (EELS). To clearly track the silver and manganese arrangements, we used high-angle annular dark-field STEM (HAADF-STEM) analysis and STEM–EDX mapping of the SMNp. As shown in Fig. 2a, individual atomic columns of silver and manganese were well resolved along the [010] zone direction, and STEM–EDX line-scanning profile provided distinct fluctuating curves of silver and manganese atoms with well-distributed oxygen elements (Fig. 2b). The simulated HAADF-STEM showed the sequence of atomic rows with different electron densities, further confirming that the striped structure was caused by silver and manganese arrangements (Fig. 2c). More striking was the detection of oxygen sites near the silver and manganese atoms by annular bright-field STEM (ABF-STEM) image (Fig. 2d), which was well matched with the crystallographic model of Ag2MnO4 structure (Supplementary Fig. 11). Furthermore, the ABF intensity profile showed the corresponding peaks of Ag2MnO4 structure (Fig. 2e). We also carried out a series of imaging and analysis for the different zones such as [123], [122], and [311] of the SMNp, and the results were summarized in Supplementary Fig. 12 in the same manner as those presented in Fig. 2. In these projections, the atomically resolved Ag2MnO4 structure was well observed, as confirmed by crystallographic models. In comparison to this, the electron microscopy and spectroscopy results of the PM showed a typical tetragonal crystal structure (Supplementary Fig. 13).

Fig. 2

Atomically resolved electron microscopy and electron energy loss spectra. a Filtered high-angle annular dark-field-scanning transmission electron microscopy (HAADF-STEM) and energy-dispersive X-ray spectroscopy (EDX) mapping image of the silver manganate nanoplate (SMNp) along the [010] zone axis with its fast Fourier transform (FFT) pattern, showing continuous arrangements of silver and manganese atoms. b Line-scanning profile showing distinct distributions of silver and manganese elements. c, d Simulated HAADF-STEM image (c), indicating the highest electron density with red color and the lowest with black, and annular bright-field (ABF)–STEM image (d) showing the Ag2MnO4 orthorhombic structure with silver (blue), manganese (red), and oxygen (purple) elements. e Corresponding ABF intensity profiles of the white box in d present the peaks of the silver and manganese atomic columns. f, g A HAADF-STEM image (f) and the corresponding electron energy loss spectroscopy (EELS) profiles (g) at the marked sites, showing Ag M4,5-edge, O K-edge, and Mn L2,3-edge. Scale bars, 1 nm (a), 0.2 nm (c, d), and 50 nm (f)

Full size image

The detailed elemental composition and distribution of the SMNp was investigated by using STEM–EDX mapping and point spectrum, and this revealed that silver and manganese atoms were evenly distributed in the plate-like structure (Supplementary Figs. 14 and 15). Interestingly, the average atomic ratio of silver and manganese elements on the SMNp was approximately 2, which strongly supported the formation of Ag2MnO4 structure (Supplementary Table 2). A series of EEL spectra were randomly collected from the STEM image (Fig. 2f), where all sites showed the identical Ag M4,5-edge, O K-edge, and Mn L2,3-edge (Fig. 2g). This implies that the plate-like region of the SMNp consists of the Ag2MnO4 structure.

### Electrocatalyst activity and stability

To investigate the ORR activity of the SMNp, we measured linear sweep voltammetry (LSV) using a rotating ring–disk electrode (RRDE) in O2-saturated electrolyte solution of 0.1 M KOH solution at 24 °C (Fig. 3a). For comparison, the ORR performances of Ag, BM, PM, and commercial 20 wt% Pt/C were also measured under the same condition. The pristine Ag nanoparticle showed the poor catalytic activity with respect to both onset potential and limiting current density. The catalytic activity of the BM and PM was higher than that of Ag nanoparticle, showing positively shifted onset potentials. Although the PM had the highest specific surface area (14.18 m2g–1), the ORR activity was limited because it contained the Mn5O8 phase having low electrical conductivity55. For the SMNp, we observed a much higher onset and half-wave potentials of 0.90 ± 0.01 and 0.80 ± 0.01 V vs. RHE (reversible hydrogen electrode) than the other samples, which was little smaller than the onset (1.05 ± 0.01 V vs. RHE) and half-wave potential (0.85 ± 0.01 V vs. RHE) of the Pt/C. It was clear that the existence of silver nanoparticles in the SMNp could significantly decrease the overpotential due to its high electrical conductivity, promoting electron transfer processes. The fluctuating current density of the SMNp at low-voltage range may result from capacitance correction because of large non-faradaic capacitance (Supplementary Fig. 16). The ORR activities of the control samples with different contents of precursors were shown in Supplementary Fig. 17. We found that the SMNp with an optimized content of silver nanoparticle (0.10 g), manganese source (0.07 g), and reducing agent (0.6 mL) showed the best electrochemical performance. We also conducted the rotation speed-dependent polarization curves for the SMNp to estimate the reaction pathways for the ORR (Supplementary Fig. 18). The Koutecky−Levich (K−L) plots of the SMNp showed the nearly parallel linear plots, which was the first-order reaction with respect to oxygen.

Fig. 3

Electrocatalytic activities for oxygen reduction reaction. a Linear scan voltammogram (LSV) curves for the Ag nanoparticle, bulk manganese oxides (BM), polyhedron manganese oxide (PM), silver manganate nanoplate (SMNp), and a commercial Pt/C catalyst at a rotating ring–disk electrode (1600 r.p.m) in O2-saturated 0.1 M KOH solution with a scan rate of 5 mV s–1. All data have been calibrated by using Ar-saturated 0.1 M KOH solution. b, c The corresponding number of transferred electrons (b) and Tafel plots (c) of the Ag, BM, PM, SMNp, and Pt/C. Id represents the limiting current density obtained at a potential of 0.30 V in a. d Chronoamperometric response of the SMNp and 20 wt% Pt/C in O2-saturated 0.1 M KOH electrolytes at 0.85 V (vs. RHE) with 1600 r.p.m showing good stability of SMNp compared with Pt/C

Full size image

To elucidate the reaction pathway for the ORR, we calculated the value of electron transfer number per oxygen molecule (n). The number of electrons for the SMNp was ~3.9, which was obviously higher than that for Ag, BM, and PM (Fig. 3b), implying that the direct four-electron pathway was governed during the ORR process56. Further, we confirmed the excellent ORR activity of the SMNp from the mass transfer-corrected Tafel plots (Fig. 3c). The slope of the SMNp at a low overpotential region showed the lowest value of 54 mV dec−1, which was even lower than Pt/C (60 mV dec−1). This result also indicated that the rate-determining step of both the SMNp and Pt/C was the formation of superoxides by one electron transfer57. In addition, a larger kinetic current density of the SMNp (1.13 mA cm−2 at 0.85 V vs. RHE) indicated a higher ORR activity, in comparison to the Ag nanoparticle, BM, and PM (Supplementary Fig. 19). Such improvements of the SMNp can be explained by the intragranular cracks and abundant dislocations in nanoplate structures, providing a wide range of oxygen adsorption and desorption sites for facile ion transport53. In terms of the manganese oxidation state, the mixed valence state (Mn3+/4+) of the SMNp confirmed by the XPS measurement could promote the oxygen bond cleavage40. In addition to the ORR activity, the electrochemical stability of the catalysts is another important factor, thus, we measured its chronoamperometric (i–t) response for the ORR (Fig. 3d). Interestingly, the durability of the SMNp showed ~17.4% higher than that of the Pt/C, which could be ascribed to ~200 mV higher equilibrium potential of Ag/Ag2O than that of Pt/PtO in alkaline solution34.

### Aluminum–air flow battery performance

The electrochemical performance of the SMNp catalyst was evaluated by aluminum–air flow batteries (AAFBs). As shown in Fig. 4a, we designed a flow-type aluminum–air cell, and this cell assembly consists of an aluminum metal anode, catalyst-loaded air electrode, and alkaline electrolyte tank (Supplementary Fig. 20). By supplying fresh electrolyte, we can avoid the precipitation of by-products, making the surface of electrodes clean2. In addition, self-discharge problem can be prevented by draining off the electrolyte, ensuring a long shelf life of the AAFBs. In comparison to a conventional static cell, the AAFB demonstrated improved peak power density of ~71.2 mW cm−2 at 100 mA cm−2, and the discharge duration of the AAFBs was 11 times longer than the static cell at 50 mA cm−2 (Supplementary Fig. 21a, b). In terms of the by-products precipitation, the surface of aluminum anode in a static cell was covered with a solid Al(OH)3 precipitate, thus causing severe cell degradation with low discharge capacity (Supplementary Fig. 21c, d).

Fig. 4

Electrochemical performance of aluminum–air flow batteries. a Schematic of the aluminum–air flow battery (AAFB) system, which includes a single stack cell, one electrolyte tank, and circulation pump. ORR indicates oxygen reduction reaction. b Power density curves of flow cells using the pristine air electrode, silver manganate nanoplate (SMNp), and Pt/C with 6 M KOH electrolyte (scan rate of 0.1 mA s−1). c Discharge curves using the pristine air electrode, SMNp, and Pt/C at 100 mA cm−2. d Mechanical charge and discharge tests using the SMNp and Pt/C at 25 mA cm−2, where the aluminum and electrolyte were replaced every cycle

Full size image

To further increase the battery performance, we used catalysts loaded with air electrodes (Ag nanoparticle, BM, PM, SMNp, and Pt/C) in the AAFBs. The discharge process was initiated after 10 min of rest with a circulating electrolyte to activate aluminum anode by eliminating the surface oxide phase. As shown in Fig. 4b and Supplementary Fig. 22, the SMNp demonstrated significantly enhanced peak power density of ~105.2 mW cm−2, compared to the pristine air electrode. This value was comparable to that of the Pt/C (~104.0 mW cm−2), and the maximum current density of the SMNp (~237 mA cm−2) was even higher than that of the Pt/C (~226 mA cm−2). Power density results of other samples were summarized in Supplementary Table 3. The effects of the ZnO additive in 6 M KOH electrolytes are shown in Supplementary Fig. 23, which increases the discharge voltage of ~0.11 V. However, we conducted flow cell tests without any additives to clearly demonstrate the electrolyte flowing system. The galvanostatic discharge tests were conducted at different constant currents of 50 and 100 mA cm−2. The specific capacity of the SMNp was ~2642 A h kgAl−1 at 50 mA cm−2, which was calculated on the basis of aluminum weight (Supplementary Fig. 24). When the current density increased to 100 mA cm−2, the SMNp showed discharge time of 7.3 h corresponding to the specific capacity of ~2843 A h kgAl−1, approaching the theoretical specific capacity of 2978 A h kgAl−1 (Fig. 4c and see Supplementary Note 1). Notably, the gravimetric and volumetric energy densities of the SMNp were ~2552 W h kgAl−1 and ~6890 W h LAl−1 at 100 mA cm−2, and these values were comparable with those of the Pt/C (~2507 W h kgAl−1 and ~6796 W h LAl−1), which was summarized in Supplementary Table 4. When the current density increased to 100 mA cm−2, the open-circuit potentials of the air electrode, SMNp, and Pt/C were ~1.42, ~1.55, and ~1.50 V, which were decreased after initiating the discharge process because of high current density (Fig. 4c). When the cells were subjected to the constant voltage test at 1 V (Supplementary Fig. 25), the SMNp exhibited the maximum current density of ~87 mA cm−2, which was higher than that of the Pt/C (~82 mA cm−2). This outstanding electrochemical performance could be originated from the synergistic effects of silver nanoparticle with high electrical conductivity and plate-like, striped Ag2MnO4 structure with abundant dislocations.

Remarkably, the AAFB with the SMNp showed excellent cycle stability upon a mechanically charging process, where the electrolyte and aluminum plate were replaced after fully discharging at 25 mA cm−2 (Fig. 4d). At the initial stage, the Pt/C showed relatively lower overpotentials than the SMNp, showing a discharge potential of ~1.24 V. However, from the second cycle, the significant potential drop was observed in the Pt/C because of degradation of platinum element in concentrated alkaline solution. The SMNp presented stable discharge curves during prolonged cycles, suggesting its chemical stability, which was agreed with the chronoamperometric response in Fig. 3d. We also confirmed that the SMNp catalyst was stably maintained after battery cycling by SEM–EDX analysis (Supplementary Fig. 26). Therefore, the choice of the silver-based materials offers the large potentials of developing high-energy AAFBs with a minimal cell degradation.

## Discussion

The origin of the improvement of cell potential and stability by the SMNp catalyst can be understood with respect to the electrical conductivity of the electrode and the degree of metal dissolution. First, we measured electrical conductivity of the catalyst-loaded air electrodes by using a through-plane conductivity measurement setup (Supplementary Fig. 27)58. As shown in Fig. 5a, the electrical conductivity of the Ag-loaded air electrode (5.05 × 10−2S cm−1) was higher than that of the Pt/C-loaded one (4.01 × 10−2S cm−1) because of lower electrical resistivity of silver than platinum. Interestingly, the SMNp revealed the highest electrical conductivities of 5.18 × 10−2S cm−1, which could be ascribed to the silver nanoparticle-distributed nanoplate configuration. This also implied that the intrinsic drawback of dislocation having poor grain-to-grain connection can be overcome by the silver element53. The electrical properties of all samples are summarized in Supplementary Table 5.

Fig. 5

Comparison of electrode properties and battery performance. a Electrical conductivity of the Ag nanoparticle, bulk manganese oxides (BM), polyhedron manganese oxide (PM), silver manganate nanoplate (SMNp), and Pt/C-loaded air electrodes. b Precious metal dissolution tests in aluminum–air flow batteries (AAFBs) using the SMNp and Pt/C with 6 M KOH electrolyte after 6 h of discharging at 50 mA cm−2. c, d Comparison of the gravimetric energy density (c) among gasoline with theoretical and practical value, AAFBs with Pt/C and SMNp (at 50 mA cm−2), and comparison of the gravimetric energy density (d) between zinc–air flow batteries (ZAFBs) and AAFBs with the SMNp at 100 mA cm−2

Full size image

At a current density of < 100 mA cm−2, we confirmed that the discharge voltage of the Pt/C was substantially higher than that of the SMNp in polarization curves (Supplementary Fig. 22), which was well matched with the results from LSV curves (Fig. 3a). However, the discharge voltage of the SMNp has started to be comparable with that of the Pt/C at a current density of > 100 mA cm−2, which eventually exceeded the discharge voltage of Pt/C. These phenomena were also confirmed by the individual discharge curves of the SMNp and Pt/C with different current densities of 25 (Fig. 4d), 50 (Supplementary Fig. 24), and 100 mA cm−2 (Fig. 4c). When we carefully observed the discharge curves in relatively low current densities of 25 and 50 mA cm−2, the overpotentials for the SMNp were higher than Pt/C, thus lowering the discharge voltage. However, the SMNp showed a comparable voltage profile to Pt/C at a high current density of 100 mA cm−2, which could be ascribed to the superior electrical conductivity of the SMNp. This was confirmed by measuring the electrical conductivity of catalysts-loaded air electrode itself (Fig. 5a and Supplementary Fig. 27). Therefore, under the current density of > 100 mA cm−2, the electrical conductivity of the electrode plays a key role for enhancing the overall electrochemical performance of aluminum–air flow battery.

In terms of the chemical stability, we analyzed the dissolution of precious metal after cycling by using inductively coupled plasma mass spectrometry (ICP-MS). The electrolytes were collected after the AAFB was discharged for 6 h at 50 mA cm−2 (Fig. 5b). The cell equipped with the Pt/C showed a concentration of platinum dissolution of 33.5 × 10−2 ppm. For the SMNp, we observed that the concentration of silver dissolution was 18 times lower than that of platinum (1.8 × 10−2 ppm). This exceptional chemical stability of silver element in the SMNp can reasonably support the results of chronoamperometric response and mechanical recharging test.

We compared the gravimetric energy density of our AAFB with gasoline59 (Fig. 5c). It was reported that the theoretical energy density of gasoline was ~13,000 W h kg−1 (~9500 W h L−1). However, the practical energy density of gasoline is ~1700 W h kg−1 (~1200 W h L−1) considering the average tank-to-wheel efficiency of 12.6%.60 Compared to this, the gravimetric energy density of our AAFBs with SMNp was ~2552 W h kgAl−1, which showed large potentials for the aluminum as an alternative energy source. The volumetric energy density of each system was also summarized in Supplementary Fig. 28. Finally, we showed that the SMNp catalyst can be also used in zinc–air flow batteries (ZAFBs) and compared with AAFBs (Fig. 5d, Supplementary Fig. 29 and Table 6). The ZAFBs with SMNp showed the discharge capacity of ~558 mA h and gravimetric energy density of ~704 W h kgZn−1 at a current density of 100 mA cm−2, which still lags behind the performance of the AAFBs. Notably, the amount of consumed metal per discharge capacity in the AAFBs was ~0.35 g A h−1, in comparison to the value of ~1.24 g A h−1 in the ZAFBs, indicating three times higher conversion efficiency of the AAFBs.

In conclusion, we have prepared a silver nanoparticle seed-mediated silver manganate nanoplate architecture for ORR. We discovered that the silver atom can migrate into the available crystal lattice and rearrange manganese oxide structure, thus creating abundant surface dislocations. The activity and durability of this material outperformed the platinum-based electrocatalyst in concentrated alkaline solution. Furthermore, we have shown that flow-based aluminum–air battery with our catalyst not only offers a route to stable, robust energy conversion device, but also brings unprecedented gravimetric and volumetric energy densities of ~2507 W h kgAl−1 and ~6890 W h LAl−1, as summarized in Supplementary Table 7. This innovative strategy prevented the precipitation of solid by-product in the cell and dissolution of a precious metal in air electrode. We believe that our AAFB system has the potential for a cost-effective and safe next-generation energy conversion system.

## Methods

### Catalyst synthesis

The silver nanoparticle-mediated silver manganate nanoplate (SMNp) was synthesized by the simple precipitation and heat-treatment process. First, 0.07 g of manganese(II) nitrate hydrate (≥98%, Sigma-Aldrich) and 0.1 g of silver nanoparticle (polyvinylpyrrolidone functionalized, particle size of <100 nm, ≥99.5%, Sigma-Aldrich) were subsequently added into 2 mL of ethanol solution under vigorous stirring with a magnetic bar. Next, to form a uniform coating manganese layer on silver nanoparticles, 0.6 mL of 8 M NaOH solution as a reducing agent was prepared by sodium hydroxide beads (≥98%, SAMCHUN), and then poured into the above-blended solution. After finishing the reduction of manganese ions and coating process, the solution was centrifuged at 4000 r.p.m. for 5 min with DI water and dried in a 200 °C oven for overnight. The resultant composite was annealed at 450 °C for 15 min at a heating rate of 5 °C min−1 under ambient air atmosphere to form silver manganate nanoplate structure. The control experiments with different contents of silver nanoparticles (0.05 and 0.2 g), manganese(II) nitrate hydrate (0.035 and 0.140 g), and 8 M NaOH solution (0.15 and 2.40 mL) were conducted with the same procedure above.

### Structural characterization

The morphology of the synthesized materials was examined using scanning electron microscopy (SEM, VERIOS 460, FEI) operating at 10 kV and high-resolution transmission electron microscope (HR-TEM, ARM300, JEOL) operating at 300 kV. Elemental mapping was attained using energy-dispersive X-ray spectroscopy (EDX) equipped with the SEM and TEM. The crystal structure analysis was performed using an X-ray diffractometer (XRD, D/Max2000, Rigaku) with Cu-Ka radiation. Surface chemistry was analyzed using X-ray photoelectron spectroscopy (XPS, Thermo Scientific Kα spectrometer, 1486.6 eV)

### Preparation of catalyst inks and working electrode

The catalyst ink was prepared using a mixture of 16 mg of the catalyst powder, 4 mg of a Ketjenblack, 800 µL of ethanol, and 200 µL of 5 wt% Nafion solution (Sigma-Aldrich). The Pt/C catalyst ink was made by adding 10 mg of Pt/C based on Vulcan XC 72 (20 wt%, Premetek Co.) powder into 800 µL of ethanol and 200 µL of 5 wt% Nafion solution. The catalyst inks were homogeneously mixed by ultrasonication, and then, 5 µL of the ink was loaded on the surface of the polished glassy carbon of the rotation ring–disk electrode (RRDE) as a working electrode. After loading ink, the working electrode was dehydrated by the vacuum chamber for 30 min. As a result, the loading levels of the synthesized catalysts and Pt/C were 0.637 mgcat cm–2 and 0.398 mg(20% Pt/C) cm–2, respectively (79.6 μgpt cm–2 for the pure Pt amount).

### Electrochemical measurements

The rotating ring–disk electrode (RRDE, ALS Co., Ltd.) measurement was conducted using the catalyst films that were deposited on a glassy carbon electrode in 0.1 M KOH electrolyte saturated with oxygen at 1600 r.p.m. A Pt wire and Hg/HgO were used as a counter and a reference electrode, respectively. Electrochemical characterization was carried out using a bipotentiostat (IviumStat) with ohmic drop correction. The ORR current was measured after the current had saturated by using a cyclic voltammetry (CV) measurement that was made for voltages of 0.20 to –0.67 V (vs. Hg/HgO) at a scan rate of 10 mV s–1. The capacitive current was corrected by means of a CV measurement in 0.1 M KOH electrolyte saturated with argon. The measured potentials (vs. Hg/HgO) were calibrated with respect to a reversible hydrogen electrode (RHE) value by adding 0.929 V to the measured potential (vs. Hg/HgO). The number of transferred electrons (n) was calculated using the equation below. The number of transferred electrons (n) was calculated using the equation below where the collection efficiency (N) was determined using 10 mM K3[Fe(CN)6] electrolyte under argon atmosphere, which was around 0.41. This value is similar to the theoretical value of 0.42. Id and Ir represent disk and ring currents, respectively.

$${n} = 4\frac{{I_d}}{{I_d + I_r{\mathrm{/}}N}}$$

The electrochemical properties of the AAFBs were evaluated by using a potentionstat/galvanostat (WBC3000, WonAtech) with a voltage cutoff of 0.4 V for a primary flow cell test and 10 h of discharge per cycle for a mechanically charging process, respectively.

### Kinetic current calculation

Kinetic current of electrocatalysts was obtained from mass transfer correction using Levich equation.

$$i_{\mathrm{measured}}^{-1} = i_{k}^{-1} + i_{d}^{-1}$$

where imeasured is the measured oxygen reduction current density, ik is the kinetic current density, and id is the limiting current density.

### Aluminum–air flow cell tests

For aluminum–air flow cell test based on the SMNp catalyst, a flow cell kit was fabricated in laboratory scale. Aluminum plate (alloy 6061, 97.93%, Alfa-Aesar) was used as an anode and 40 ml of 6 M KOH as an electrolyte. No separator was used and the air electrode was prepared via a homogenizer to form homogeneous gas diffusion layer (GDL). First, activated charcoal (Darco G60A, Sigma-Aldrich) and catalysts (including Pt/C) were mixed without solvents at 5000 r.p.m. for 2 min. Next, the slurry with the same loading levels for all catalysts was fabricated from a dry-mixed activated charcoal/catalyst mixture and polytetrafluoroethylene binder (60 wt% PTFE emulsion in water, Sigma-Aldrich) at a weight ratio of 6:1:3 with 4 ml of isopropanol and 2 ml of acetone at 5000 r.p.m. for 30 min and pasted on the nickel foam using roll press machine with a thickness of ~700 μm. The pristine air electrode was made by the same procedure at a weight ratio of 7:3 for activated charcoal and PTFE binder. The GDL was hot-pressed at 120 °C for 5 min attached with a PTFE film to ensure proper gas distribution and avoid leakage problems. For a mechanically rechargeable test, the aluminum plate and electrolyte were replaced after discharging at 25 mA cm−2 for 10 h. The air electrodes were continuously used without replacement to confirm the cycle stability. The flow rate of electrolytes for flow cell test was 100 mL min−1.

## Data availability

The data that support the findings of this study are available from the corresponding author upon request.

## References

1. 1.

   Armand, M. & Tarascon, J. M. Building better batteries. Nature 451, 652–657 (2008).

   ADS Article PubMed CAS Google Scholar

2. 2.

   Park, M., Ryu, J., Wang, W. & Cho, J. Material design and engineering of next-generation flow-battery technologies. Nat. Rev. Mater. 2, 16080 (2016).

   ADS Article CAS Google Scholar

3. 3.

   Shkolnikov, E. I., Zhuk, A. Z. & Vlaskin, M. S. Aluminum as energy carrier: feasibility analysis and current technologies overview. Renew. Sust. Energ. Rev. 15, 4611–4623 (2011).

   Article CAS Google Scholar

4. 4.

   Li, Q. & Bjerrum, N. J. Aluminum as anode for energy storage and conversion: a review. J. Power Sources 110, 1–10 (2002).

   ADS Article CAS Google Scholar

5. 5.

   Elia, G. A. et al. An overview and future perspectives of aluminum batteries. Adv. Mater. 28, 7564–7579 (2016).

   Article PubMed CAS Google Scholar

6. 6.

   Chen, L. D., Nørskov, J. K. & Luntz, A. C. Al–air batteries:fundamental thermodynamic limitations from first-principles theory. J. Phys. Chem. Lett. 6, 175–179 (2014).

   Article PubMed CAS Google Scholar

7. 7.

   Egan, D. R. et al. Developments in electrode materials and electrolytes for aluminium-air batteries. J. Power Sources 236, 293–310 (2013).

   Article CAS Google Scholar

8. 8.

   Li, Y. & Dai, H. Recent advances in zinc-air batteries. Chem. Soc. Rev. 43, 5257–5275 (2014).

   Article PubMed CAS Google Scholar

9. 9.

   Mokhtar, M. et al. Recent developments in materials for aluminum-air batteries: a review. Ind. Eng. Chem. Res. 32, 1–20 (2015).

   Article CAS Google Scholar

10. 10.

    Yu, Y. et al. Laser sintering of printed anodes for al-air batteries. J. Electrochem. Soc. 165, A584–A592 (2018).

    Article CAS Google Scholar

11. 11.

    Fan, L., Lu, H., Leng, J., Sun, Z. & Chen, C. The study of industrial aluminum alloy as anodes for aluminum-air batteries in alkaline electrolytes. J. Electrochem. Soc. 163, A8–A12 (2016).

    Article CAS Google Scholar

12. 12.

    Cho, Y.-J., Park, I.-J., Lee, H.-J. & Kim, J.-G. Aluminum anode for aluminum–air battery—part i: Influence of aluminum purity. J. Power Sources 277, 370–378 (2015).

    ADS Article CAS Google Scholar

13. 13.

    Ma, J. et al. Influences of l-cysteine/zinc oxide additive on the electrochemical behavior of pure aluminum in alkaline solution. J. Electrochem. Soc. 165, A266–A272 (2018).

    Article CAS Google Scholar

14. 14.

    Grishina, E. et al. Improvement of aluminum-air battery performances by the application of flax straw extract. ChemSusChem 9, 2103–2111 (2016).

    Article PubMed CAS Google Scholar

15. 15.

    Wang, L. et al. A high-capacity dual-electrolyte aluminum/air electrochemical cell. RSC Adv. 4, 30857–30863 (2014).

    Article CAS Google Scholar

16. 16.

    Xu, Y., Zhao, Y., Ren, J., Zhang, Y. & Peng, H. An all-solid-state fiber-shaped aluminum-air battery with flexibility, stretchability, and high electrochemical performance. Angew. Chem. Int. Ed. 55, 7979–7982 (2016).

    Article CAS Google Scholar

17. 17.

    Gareth, F. et al. A low cost, disposable cable-shaped al-air battery for portable biosensors. J. Micromech. Microeng. 26, 055011 (2016).

    Article CAS Google Scholar

18. 18.

    Li, J. et al. Cu-MOF-derived Cu/Cu2O nanoparticles and cunxcy species to boost oxygen reduction activity of ketjenblack carbon in al-air battery. ACS Sustain. Chem. Eng. 6, 413–421 (2018).

    Article CAS Google Scholar

19. 19.

    Choi, S. et al. Shape-reconfigurable aluminum-air batteries. Adv. Funct. Mater. 27, 1702244, (2017).

20. 20.

    Zhang, J., Zhao, Z., Xia, Z. & Dai, L. A metal-free bifunctional electrocatalyst for oxygen reduction and oxygen evolution reactions. Nat. Nanotechnol. 10, 444–452 (2015).

    ADS Article PubMed CAS Google Scholar

21. 21.

    Yan, X., Jia, Y., Chen, J., Zhu, Z. & Yao, X. Defective-activated-carbon-supported Mn–Co nanoparticles as a highly efficient electrocatalyst for oxygen reduction. Adv. Mater. 28, 8771–8778 (2016).

    Article PubMed CAS Google Scholar

22. 22.

    Li, G. et al. Pomegranate-inspired design of highly active and durable bifunctional electrocatalysts for rechargeable metal-air batteries. Angew. Chem. Int. Ed. 55, 4977–4982 (2016).

    Article CAS Google Scholar

23. 23.

    Zhou, Y. et al. Oxygen reduction at very low overpotential on nanoporous ag catalysts. Adv. Energy Mater. 5, 1500149 (2015).

    Article CAS Google Scholar

24. 24.

    Huang, X. et al. High-performance transition metal–doped Pt3Ni octahedra for oxygen reduction reaction. Science 348, 1230–1234 (2015).

    ADS Article PubMed CAS Google Scholar

25. 25.

    Xia, B. Y. et al. A metal–organic framework-derived bifunctional oxygen electrocatalyst. Nat. Energy 1, 15006 (2016).

    ADS Article CAS Google Scholar

26. 26.

    Wu, H. H. et al. Highly doped and exposed Cu(i)-N active sites within graphene towards efficient oxygen reduction for zinc-air batteries. Energy Environ. Sci. 9, 3736–3745 (2016).

    Article CAS Google Scholar

27. 27.

    Zitolo, A. et al. Identification of catalytic sites for oxygen reduction in iron- and nitrogen-doped graphene materials. Nat. Mater. 14, 937–942 (2015).

    ADS Article PubMed CAS Google Scholar

28. 28.

    Liang, Y. et al. Co3O4 nanocrystals on graphene as a synergistic catalyst for oxygen reduction reaction. Nat. Mater. 10, 780–786 (2011).

    ADS Article PubMed CAS Google Scholar

29. 29.

    Liu, K. et al. Co3O4–CeO2/C as a highly active electrocatalyst for oxygen reduction reaction in al-air batteries. ACS Appl. Mater. Interfaces 8, 34422–34430 (2016).

    ADS Article PubMed CAS Google Scholar

30. 30.

    Li, F. et al. Ag/Fe3O4-N-doped ketjenblack carbon composite as highly efficient oxygen reduction catalyst in al-air batteries. J. Electrochem. Soc. 164, A3595–A3601 (2017).

    Article CAS Google Scholar

31. 31.

    Li, J. et al. Fe/N co-doped carbon materials with controllable structure as highly efficient electrocatalysts for oxygen reduction reaction in al-air batteries. Energy Storage Mater. 8, 49–58 (2017).

    Article Google Scholar

32. 32.

    Li, J. et al. Co3O4/Co-N-C modified ketjenblack carbon as an advanced electrocatalyst for al-air batteries. J. Power Sources 343, 30–38 (2017).

    ADS Article CAS Google Scholar

33. 33.

    Tomantschger, K., Findlay, R., Hanson, M., Kordesch, K. & Srinivasan, S. Degradation modes of alkaline fuel cells and their components. J. Power Sources 39, 21–41 (1992).

    ADS Article CAS Google Scholar

34. 34.

    Holewinski, A., Idrobo, J.-C. & Linic, S. High-performance Ag–Co alloy catalysts for electrochemical oxygen reduction. Nat. Chem. 6, 828–834 (2014).

    Article PubMed CAS Google Scholar

35. 35.

    Park, J. et al. Single crystalline pyrochlore nanoparticles with metallic conduction as efficient bi-functional oxygen electrocatalysts for zn-air batteries. Energy Environ. Sci. 10, 129–136 (2017).

    Article CAS Google Scholar

36. 36.

    Wang, X. et al. Palladium–platinum core–shell icosahedra with substantially enhanced activity and durability towards oxygen reduction. Nat. Commun. 6, 7594 (2015).

    Article PubMed PubMed Central Google Scholar

37. 37.

    Suntivich, J. et al. Design principles for oxygen-reduction activity on perovskite oxide catalysts for fuel cells and metal-air batteries. Nat. Chem. 3, 546–550 (2011).

    Article PubMed CAS Google Scholar

38. 38.

    Wang, H. et al. Direct and continuous strain control of catalysts with tunable battery electrode materials. Science 354, 1031–1036 (2016).

    ADS Article PubMed CAS Google Scholar

39. 39.

    Masa, J. et al. MnxOy/NC and CoxOy/NC nanoparticles embedded in a nitrogen-doped carbon matrix for high-performance bifunctional oxygen electrodes. Angew. Chem. Int. Ed. 53, 8508–8512 (2014).

    Article CAS Google Scholar

40. 40.

    Stoerzinger, K. A., Risch, M., Han, B. & Shao-Horn, Y. Recent insights into manganese oxides in catalyzing oxygen reduction kinetics. ACS Catal. 5, 6021–6031 (2015).

    Article CAS Google Scholar

41. 41.

    Gorlin, Y., Chung, C.-J., Nordlund, D., Clemens, B. M. & Jaramillo, T. F. Mn3O4 supported on glassy carbon: An active non-precious metal catalyst for the oxygen reduction reaction. ACS Catal. 2, 2687–2694 (2012).

    Article CAS Google Scholar

42. 42.

    Cheng, F., Su, Y., Liang, J., Tao, Z. & Chen, J. MnO2-based nanostructures as catalysts for electrochemical oxygen reduction in alkaline media. Chem. Mat. 22, 898–905 (2010).

    Article CAS Google Scholar

43. 43.

    Cheng, F., Shen, J., Ji, W., Tao, Z. & Chen, J. Selective synthesis of manganese oxide nanostructures for electrocatalytic oxygen reduction. ACS Appl. Mater. Interfaces 1, 460–466 (2009).

    Article PubMed CAS Google Scholar

44. 44.

    Chen, Z. et al. Recent advances in manganese oxide nanocrystals: Fabrication, characterization, and microstructure. Chem. Rev. 112, 3833–3855 (2012).

    ADS Article PubMed CAS Google Scholar

45. 45.

    Gao, T. et al. Synthesis and properties of layered-structured Mn5O8 nanorods. J. Phys. Chem. C. 114, 922–928 (2010).

    Article CAS Google Scholar

46. 46.

    Park, M. et al. Large-scale synthesis of ultrathin manganese oxide nanoplates and their applications to T1 MRI contrast agents. Chem. Mat. 23, 3318–3324 (2011).

    Article CAS Google Scholar

47. 47.

    Wei, W., Cui, X., Chen, W. & Ivey, D. G. Manganese oxide-based materials as electrochemical supercapacitor electrodes. Chem. Soc. Rev. 40, 1697–1721 (2011).

    Article PubMed CAS Google Scholar

48. 48.

    El-Deab, M. S. & Ohsaka, T. Manganese oxide nanoparticles electrodeposited on platinum are superior to platinum for oxygen reduction. Angew. Chem. Int. Ed. 45, 5963–5966 (2006).

    Article CAS Google Scholar

49. 49.

    Thapa, A. K., Saimen, K. & Ishihara, T. Pd / MnO2 air electrode catalyst for rechargeable lithium/air battery. Electrochem. Solid-State Lett. 13, A165–A167 (2010).

    Article CAS Google Scholar

50. 50.

    Li, Y., Wang, Z. & Zhang, Y. Ultrafine Ag/MnOx nanowire-constructed hair-like nanoarchitecture: In situ synthesis, formation mechanism and its supercapacitive property. J. Alloy. Compd. 644, 47–53 (2015).

    Article CAS Google Scholar

51. 51.

    Lee, K., Ahmed, M. S. & Jeon, S. Electrochemical deposition of silver on manganese dioxide coated reduced graphene oxide for enhanced oxygen reduction reaction. J. Power Sources 288, 261–269 (2015).

    ADS Article CAS Google Scholar

52. 52.

    Wu, Q. et al. Electrocatalytic activity and stability of Ag-MnOx/C composites toward oxygen reduction reaction in alkaline solution. Electrochim. Acta 123, 167–175 (2014).

    Article CAS Google Scholar

53. 53.

    Yan, P. et al. Intragranular cracking as a critical barrier for high-voltage usage of layer-structured cathode for lithium-ion batteries. Nat. Commun. 8, 14101 (2017).

    ADS Article PubMed CAS PubMed Central Google Scholar

54. 54.

    Yang, H. et al. Imaging screw dislocations at atomic resolution by aberration-corrected electron optical sectioning. Nat. Commun. 6, 7266 (2015).

    Article PubMed CAS PubMed Central Google Scholar

55. 55.

    Augustin, M. et al. Manganese oxide phases and morphologies: A study on calcination temperature and atmospheric dependence. Beilstein J. Nanotechnol. 6, 47–59 (2015).

    Article PubMed CAS PubMed Central Google Scholar

56. 56.

    Lee, J.-S. et al. Composites of a prussian blue analogue and gelatin-derived nitrogen-doped carbon-supported porous spinel oxides as electrocatalysts for a zn-air battery. Adv. Energy Mater. 6, 1601052 (2016).

    Article CAS Google Scholar

57. 57.

    Damjanovic, A., Sepa, D. B. & Vojnovic, M. V. New evidence supports the proposed mechanism for O2 reduction at oxide free platinum electrodes. Electrochim. Acta 24, 887–889 (1979).

    Article CAS Google Scholar

58. 58.

    Park, M., Jung, Y. J., Ryu, J. & Cho, J. Material selection and optimization for highly stable composite bipolar plates in vanadium redox flow batteries. J. Mater. Chem. A 2, 15808–15815 (2014).

    Article CAS Google Scholar

59. 59.

    Rahman, M. A., Wang, X. & Wen, C. High energy density metal-air batteries: A review. J. Electrochem. Soc. 160, A1759–A1771 (2013).

    Article CAS Google Scholar

60. 60.

    Girishkumar, G., McCloskey, B., Luntz, A. C., Swanson, S. & Wilcke, W. Lithium-air battery: promise and challenges. J. Phys. Chem. Lett. 1, 2193–2203 (2010).

    Article CAS Google Scholar

Download references

## Acknowledgements

This work was supported by the 2018 Research Fund (1.180019.01 and 1.180033.01) of Ulsan National Institute of Science and Technology (UNIST). Also, a global Ph.D. Fellowship Program through the National Research Foundation of Korea (NRF) funded by the Ministry of Education (2014H1A2A1020302) is greatly acknowledged.

## Author information

Author notes

1. Joohyuk Park

   Present address: Department of Materials, Parks Road, University of Oxford, Oxford, OX1 3PH, UK

2. These authors contributed equally: Jaechan Ryu, Haeseong Jang.

### Affiliations

1. Department of Energy Engineering, School of Energy and Chemical Engineering, Ulsan National Institute of Science and Technology (UNIST), 50, UNIST-gil, Ulsan, 44919, Republic of Korea

   Jaechan Ryu, Haeseong Jang, Joohyuk Park, Youngshin Yoo, Minjoon Park & Jaephil Cho

Authors

1. Jaechan Ryu
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Haeseong Jang
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Joohyuk Park
   View author publications

   You can also search for this author in PubMed Google Scholar

4. Youngshin Yoo
   View author publications

   You can also search for this author in PubMed Google Scholar

5. Minjoon Park
   View author publications

   You can also search for this author in PubMed Google Scholar

6. Jaephil Cho
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

J.R., H.J. and M.P. designed the experimental plans. J.R. synthesized the electrocatalysts, conducted the RRDE measurements, flow cell experiments, structural analysis, crystallographic modeling, and wrote the initial draft of the manuscript. H.J. carried out the synthesis of electrocatalysts and RRDE measurements. J.P. participated in the calculation of the number of transferred electrons and FFT patterns. J.R. and Y.Y. planned and conducted HR-TEM experiments and analysis. J.R., M.P. and J.C. collaborated in writing the final manuscript.

### Corresponding authors

Correspondence to Minjoon Park or Jaephil Cho.

## Ethics declarations

### Competing interests

The authors declare that they have no competing interests.

## Additional information

Publisher's note: Springer Nature remains neutral with regard to jurisdictional claims in published maps and institutional affiliations.

## Electronic supplementary material

### Supplementary Information

### Peer Review File

## Rights and permissions

Open Access This article is licensed under a Creative Commons Attribution 4.0 International License, which permits use, sharing, adaptation, distribution and reproduction in any medium or format, as long as you give appropriate credit to the original author(s) and the source, provide a link to the Creative Commons license, and indicate if changes were made. The images or other third party material in this article are included in the article’s Creative Commons license, unless indicated otherwise in a credit line to the material. If material is not included in the article’s Creative Commons license and your intended use is not permitted by statutory regulation or exceeds the permitted use, you will need to obtain permission directly from the copyright holder. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/.

Reprints and Permissions

## About this article

### Cite this article

Ryu, J., Jang, H., Park, J. et al. Seed-mediated atomic-scale reconstruction of silver manganate nanoplates for oxygen reduction towards high-energy aluminum-air flow batteries. Nat Commun 9, 3715 (2018). https://doi.org/10.1038/s41467-018-06211-3

Download citation

- Received: 11 July 2018

- Accepted: 27 August 2018

- Published: 13 September 2018

- DOI: https://doi.org/10.1038/s41467-018-06211-3

## Further reading

- ### Co single-atoms on ultrathin N-doped porous carbon via a biomass complexation strategy for high performance metal–air batteries

  - Yanqiu Wang
  - , Baoying Yu
  - , Kang Liu
  - , Xuetao Yang
  - , Min Liu
  - , Ting-Shan Chan
  - , Xiaoqing Qiu
  - , Jie Li
  - & Wenzhang Li

  Journal of Materials Chemistry A (2020)

- ### Interrogation of the Reaction Mechanism in a Na–O2 Battery Using In Situ Transmission Electron Microscopy

  - Shaobo Han
  - , Chao Cai
  - , Fei Yang
  - , Yuanmin Zhu
  - , Qian Sun
  - , Yun Guang Zhu
  - , Hui Li
  - , Haijiang Wang
  - , Yang Shao-Horn
  - , Xueliang Sun
  - & Meng Gu

  ACS Nano (2020)

- ### Binary FeCo-N-doped carbon/carbon nanotube composites for efficient oxygen reduction and high-performance aluminum-air battery

  - Mei Guo
  - , Xin Zhang
  - , Tianhua Yang
  - , Qidong Dang
  - , Xuejin Li
  - , Yaqun Wang
  - & Guoxin Zhang

  Journal of Power Sources (2020)

- ### Direct laser writing of graphene electrodes

  - Guijun Li

  Journal of Applied Physics (2020)

- ### Improved lithium and sodium ion storage properties of WS2 anode with three-layer shell structure

  - Tingting Li
  - , Ruisong Guo
  - , Yani Luo
  - , Fuyun Li
  - , Leichao Meng
  - , Xiaohong Sun
  - , Zhiwei Yang
  - , Honglin Luo
  - & Yizao Wan

  Electrochimica Acta (2020)

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF
Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.
Enter your email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing